==> hsfs-2.5.16.tar.gz: hsfs-2.5.16/hsfs/constructor/hudi_feature_group_alias.py <==
#
#   Copyright 2020 Logical Clocks AB
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#

import humps

from hsfs import feature_group as feature_group_module


class HudiFeatureGroupAlias:
    def __init__(
        self,
        feature_group,
        alias,
        left_feature_group_end_timestamp=None,
        left_feature_group_start_timestamp=0,
    ):
        self._feature_group = feature_group_module.FeatureGroup.from_response_json(
            feature_group
        )
        self._alias = alias
        self._left_feature_group_start_timestamp = left_feature_group_start_timestamp
        self._left_feature_group_end_timestamp = left_feature_group_end_timestamp

    @classmethod
    def from_response_json(cls, json_dict):
        json_decamelized = humps.decamelize(json_dict)
        return cls(**json_decamelized)

    @property
    def feature_group(self):
        return self._feature_group

    @property
    def alias(self):
        return self._alias

    @property
    def left_feature_group_start_timestamp(self):
        return self._left_feature_group_start_timestamp

    @property
    def left_feature_group_end_timestamp(self):
        return self._left_feature_group_end_timestamp

==> hsfs-3.0.0rc0.tar.gz: hsfs-3.0.0rc0/hsfs/constructor/hudi_feature_group_alias.py <==
#
#   Copyright 2020 Logical Clocks AB
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#

import humps
import time

from hsfs import feature_group as feature_group_module


class HudiFeatureGroupAlias:
    def __init__(
        self,
        feature_group,
        alias,
        left_feature_group_end_timestamp=None,
        left_feature_group_start_timestamp=0,
    ):
        self._feature_group = feature_group_module.FeatureGroup.from_response_json(
            feature_group
        )
        self._alias = alias
        self._left_feature_group_start_timestamp = left_feature_group_start_timestamp
        self._left_feature_group_end_timestamp = (
            left_feature_group_end_timestamp
            if left_feature_group_end_timestamp
            # if there is no end commit, set the time to now.
            # *1000 as Hudi deals with commit times in milliseconds and
            # later on HSFS does /1000
            else time.time() * 1000
        )

    @classmethod
    def from_response_json(cls, json_dict):
        json_decamelized = humps.decamelize(json_dict)
        return cls(**json_decamelized)

    @property
    def feature_group(self):
        return self._feature_group

    @property
    def alias(self):
        return self._alias

    @property
    def left_feature_group_start_timestamp(self):
        return self._left_feature_group_start_timestamp

    @property
    def left_feature_group_end_timestamp(self):
        return self._left_feature_group_end_timestamp
